Coverage report

# Coverage report: 83%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 98 | 17 | 2 | 83%
/home/agp/Documents/me/code/brotation/brotation/__init__.py | 3 | 0 | 0 | 100%
/home/agp/Documents/me/code/brotation/brotation/brotation.py | 73 | 2 | 0 | 97%
/home/agp/Documents/me/code/brotation/brotation/cli.py | 22 | 15 | 2 | 32%

No items found using the specified filter.